==========================
Frequently Asked questions
==========================

Work in progress...

Our `Slack workspace <https://inlab-geo.slack.com>`_ is open to the community!
Feel free to get in for more conversation.
